aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/runtime/GLES_COMPUTE
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/runtime/GLES_COMPUTE')
-rw-r--r--arm_compute/runtime/GLES_COMPUTE/functions/GCArithmeticAddition.h24
-rw-r--r--arm_compute/runtime/GLES_COMPUTE/functions/GCPixelWiseMultiplication.h13
2 files changed, 20 insertions, 17 deletions
diff --git a/arm_compute/runtime/GLES_COMPUTE/functions/GCArithmeticAddition.h b/arm_compute/runtime/GLES_COMPUTE/functions/GCArithmeticAddition.h
index a16ab2d1ab..65bbacf272 100644
--- a/arm_compute/runtime/GLES_COMPUTE/functions/GCArithmeticAddition.h
+++ b/arm_compute/runtime/GLES_COMPUTE/functions/GCArithmeticAddition.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2016-2019 ARM Limited.
+ * Copyright (c) 2016-2020 ARM Limited.
*
* SPDX-License-Identifier: MIT
*
@@ -41,22 +41,24 @@ class GCArithmeticAddition : public IGCSimpleFunction
public:
/** Initialise the kernel's inputs, output and convertion policy.
*
* @param[in] input1 First tensor input. Data types supported: F16.
* @param[in] input2 Second tensor input. Data types supported: F16.
* @param[out] output Output tensor. Data types supported: F16.
* @param[in] policy Policy to use to handle overflow.
*/
- void configure(const IGCTensor *input1, const IGCTensor *input2, IGCTensor *output, ConvertPolicy policy);
+ void configure(const IGCTensor *input1, const IGCTensor *input2, IGCTensor *output, ConvertPolicy policy, const ActivationLayerInfo &act_info = ActivationLayerInfo());
/** Static function to check if given info will lead to a valid configuration of @ref GCArithmeticAddition
*
* @param[in] input1 First tensor input info. Data types supported: F16.
* @param[in] input2 Second tensor input info. Data types supported: F16.
* @param[in] output Output tensor info. Data types supported: F16.
* @param[in] policy Policy to use to handle overflow.
*
* @return a status
*/
- static Status validate(const ITensorInfo *input1, const ITensorInfo *input2, const ITensorInfo *output, ConvertPolicy policy);
+ static Status validate(const ITensorInfo *input1, const ITensorInfo *input2, const ITensorInfo *output, ConvertPolicy policy, const ActivationLayerInfo &act_info = ActivationLayerInfo());
};
}
#endif /* ARM_COMPUTE_GCARITHMETICADDITION_H */
@@ -41,22 +41,24 @@ class GCArithmeticAddition : public IGCSimpleFunction
/** Initialise the kernel's inputs, output and convertion policy.
*
- * @param[in] input1 First tensor input. Data types supported: F16.
- * @param[in] input2 Second tensor input. Data types supported: F16.
- * @param[out] output Output tensor. Data types supported: F16.
- * @param[in] policy Policy to use to handle overflow.
+ * @param[in] input1 First tensor input. Data types supported: F16.
+ * @param[in] input2 Second tensor input. Data types supported: F16.
+ * @param[out] output Output tensor. Data types supported: F16.
+ * @param[in] policy Policy to use to handle overflow.
+ * @param[in] act_info (Optional) Activation layer information in case of a fused activation. Currently not supported.
*/
@@ -41,22 +41,24 @@ class GCArithmeticAddition : public IGCSimpleFunction
/** Static function to check if given info will lead to a valid configuration of @ref GCArithmeticAddition
*
- * @param[in] input1 First tensor input info. Data types supported: F16.
- * @param[in] input2 Second tensor input info. Data types supported: F16.
- * @param[in] output Output tensor info. Data types supported: F16.
- * @param[in] policy Policy to use to handle overflow.
+ * @param[in] input1 First tensor input info. Data types supported: F16.
+ * @param[in] input2 Second tensor input info. Data types supported: F16.
+ * @param[in] output Output tensor info. Data types supported: F16.
+ * @param[in] policy Policy to use to handle overflow.
+ * @param[in] act_info (Optional) Activation layer information in case of a fused activation. Currently not supported.
*
* @return a status
diff --git a/arm_compute/runtime/GLES_COMPUTE/functions/GCPixelWiseMultiplication.h b/arm_compute/runtime/GLES_COMPUTE/functions/GCPixelWiseMultiplication.h
index 6baa0de501..201e131dd9 100644
--- a/arm_compute/runtime/GLES_COMPUTE/functions/GCPixelWiseMultiplication.h
+++ b/arm_compute/runtime/GLES_COMPUTE/functions/GCPixelWiseMultiplication.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2017-2019 ARM Limited.
+ * Copyright (c) 2017-2020 ARM Limited.
*
* SPDX-License-Identifier: MIT
*
@@ -37,12 +37,13 @@ class GCPixelWiseMultiplication : public IGCSimpleFunction
public:
/** Initialise the kernel's inputs, output and convertion policy.
*
* @param[in] input1 First tensor input. Data types supported: F32.
* @param[in] input2 Second tensor input. Data types supported: Same as @p input1.
* @param[out] output Output tensor. Data types supported: Same as @p input1.
* @param[in] scale Scale to apply after multiplication. Must be a positive value.
*/
- void configure(const IGCTensor *input1, const IGCTensor *input2, IGCTensor *output, float scale);
+ void configure(const IGCTensor *input1, const IGCTensor *input2, IGCTensor *output, float scale, const ActivationLayerInfo &act_info = ActivationLayerInfo());
};
}
#endif /*ARM_COMPUTE_GCPIXELWISEMULTIPLICATION_H */
@@ -37,12 +37,13 @@ class GCPixelWiseMultiplication : public IGCSimpleFunction
/** Initialise the kernel's inputs, output and convertion policy.
*
- * @param[in] input1 First tensor input. Data types supported: F32.
- * @param[in] input2 Second tensor input. Data types supported: Same as @p input1.
- * @param[out] output Output tensor. Data types supported: Same as @p input1.
- * @param[in] scale Scale to apply after multiplication. Must be a positive value.
+ * @param[in] input1 First tensor input. Data types supported: F32.
+ * @param[in] input2 Second tensor input. Data types supported: Same as @p input1.
+ * @param[out] output Output tensor. Data types supported: Same as @p input1.
+ * @param[in] scale Scale to apply after multiplication. Must be a positive value.
+ * @param[in] act_info (Optional) Activation layer information in case of a fused activation. Currently not supported.
*/